package com.ecosway.connector.dotcom.controller;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ecosway.connector.services.dotcom.domain.MemberInfo;
import com.ecosway.connector.services.dotcom.domain.MemberRegistrationRequest;
import com.ecosway.connector.services.dotcom.service.RegistrationServices;

/**
 * The front-end controller for {@link RegistrationServices}.
 * 
 * @author chinyeh
 *
 */
@Controller
@RequestMapping(value = "/reg-services")
public class RegistrationController {

	private RegistrationServices registrationServices;

	/**
	 * @param registrationServices the registration services
	 */
	@Autowired
	public void setRegistrationServices(
			RegistrationServices registrationServices) {
		this.registrationServices = registrationServices;
	}
	
	/**
	 * Register the member.
	 * 
	 * @param request the member registration request
	 * @return true if success
	 */
	@RequestMapping(value = "/shopper", method = RequestMethod.POST)
	@ResponseBody
	public boolean registerMember(
			@RequestBody MemberRegistrationRequest request) {
		return registrationServices.registerMember(request);
		
	}
	
	/**
	 * Retrieves the member info using the shopper reference no.
	 * 
	 * @param shopperRefNo the shopper reference no.
	 * @return the member info
	 */
	@RequestMapping(value = "/shopper/{shopperRefNo}", 
			method = RequestMethod.GET)
	@ResponseBody
	public MemberInfo retrieveMemberInfo(@PathVariable int shopperRefNo) {
		return registrationServices.queryMember(shopperRefNo);
	}
}
