package com.ecosway.connector.services.dotcom.dao;

import java.util.List;

import com.ecosway.connector.services.dotcom.domain.ShopperAddress;

/**
 * DAO for the shopper address table.
 * 
 * @author chinyeh
 *
 */
public interface ShopperAddressDao {

	/**
	 * Retrieves the shopper address using address reference number.
	 * 
	 * @param addressRefNo the shopper address's reference no.
	 * @return the shopper address object if found; else null
	 */
	ShopperAddress retrieveByRefNo(int addressRefNo);
	
	/**
	 * Retrieves the shopper address using shopper reference number.
	 * 
	 * @param shopperRefNo the shopper reference no.
	 * @return the list of shopper addresses if found
	 */
	List<ShopperAddress> retrieveByShopperRefNo(int shopperRefNo);
	
	/**
	 * Persists the given shopper address object.
	 * 
	 * @param shopperAddress the shopper address to be saved
	 * @return the number of affected row
	 */
	int save(ShopperAddress shopperAddress);
}
