package com.ecosway.connector.services.dotcom.service.impl;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.List;

import javax.sql.DataSource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import com.ecosway.connector.services.dotcom.dao.ShopperAddressDao;
import com.ecosway.connector.services.dotcom.dao.ShopperDao;
import com.ecosway.connector.services.dotcom.dao.impl.ShopperAddressDaoImpl;
import com.ecosway.connector.services.dotcom.dao.impl.ShopperDaoImpl;
import com.ecosway.connector.services.dotcom.domain.MemberInfo;
import com.ecosway.connector.services.dotcom.domain.MemberRegistrationRequest;
import com.ecosway.connector.services.dotcom.domain.ShopperAddress;
import com.ecosway.connector.services.dotcom.service.RegistrationServices;

/**
 * A simple implementation of {@link RegistrationServices}.
 * @author chinyeh
 *
 */
@Service
public class RegistrationServicesImpl implements RegistrationServices {

	private DataSource dataSource;
	
	/**
	 * @param dataSource the data source
	 */
	@Autowired
	@Qualifier("storeDataSource")
	public void setDataSource(DataSource dataSource) {
		this.dataSource = dataSource;
	}
	
	/**
	 * {@inheritDoc}
	 */
	public MemberInfo queryMember(int shopperReferenceNo) {
		MemberInfo response = new MemberInfo();
		
		Connection connection = null;
		try {
			connection = dataSource.getConnection();
			ShopperDao shopperDao = new ShopperDaoImpl(connection);
			ShopperAddressDao addressDao = 
				new ShopperAddressDaoImpl(connection); 
			
			response.setShopper(
					shopperDao.retrieveByRefNo(shopperReferenceNo));
			
			List<ShopperAddress> listOfAddress = 
				addressDao.retrieveByShopperRefNo(shopperReferenceNo); 
			
			if ((listOfAddress != null) && (!listOfAddress.isEmpty())) {
				// return first found record
				response.setShopperAddress(listOfAddress.get(0));
			}
		} catch (SQLException ex) {
			throw new RuntimeException(ex);
		} finally {
			try {
				if (connection != null) {
					connection.close();
				}
			} catch (SQLException ex) {
				throw new RuntimeException(ex);
			}
		}
		
		return response;
	}

	/**
	 * {@inheritDoc}
	 */
	public boolean registerMember(
			MemberRegistrationRequest registrationRequest) {
		// TODO Auto-generated method stub
		return false;
	}

}
